==> haskell-tamarin-prover-term-1.6.0-46-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-term.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tamarin-prover-term
version:              1.6.0
visibility:           public
id:                   tamarin-prover-term-1.6.0-HlGl4TzWZRaKQGUggghkNL
key:                  tamarin-prover-term-1.6.0-HlGl4TzWZRaKQGUggghkNL
license:              LicenseRef-GPL
copyright:
    Benedikt Schmidt, Simon Meier, Jannik Dreier, Ralf Sasse, ETH Zurich, 2010-2018

maintainer:
    Simon Meier <simon.meier@inf.ethz.ch>,
    Jannik Dreier <research@jannikdreier.net>,
    Ralf Sasse <ralf.sasse@gmail.com>

author:
    Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
    Simon Meier <simon.meier@inf.ethz.ch>,
    Jannik Dreier <research@jannikdreier.net>,
    Ralf Sasse <ralf.sasse@gmail.com>

homepage:             https://tamarin-prover.github.io/
synopsis:             Term manipulation library for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

    This library provides term manipulation infrastructure
    (matching, unification, narrowing, finite variants) for
    the Tamarin prover. It uses maude
    (<http://maude.cs.uiuc.edu/>) as a backend for
    normalization, equational matching, and unification.

category:             Theorem Provers
abi:                  960e90a11b9de746a79a6f6329c947bd
exposed:              True
exposed-modules:
    Term.Builtin.Convenience Term.Builtin.Rules Term.Builtin.Signature
    Term.LTerm Term.Maude.Parser Term.Maude.Process
    Term.Maude.Signature Term.Maude.Types Term.Narrowing.Variants
    Term.Narrowing.Variants.Check Term.Narrowing.Variants.Compute
    Term.Positions Term.Rewriting.Definitions Term.Rewriting.Norm
    Term.Substitution Term.Subsumption Term.SubtermRule
    Term.Unification Term.UnitTests Term.VTerm

hidden-modules:
    Term.Term Term.Term.Classes Term.Term.Raw Term.Term.FunctionSymbols
    Term.Narrowing.Narrow Term.Substitution.SubstVFree
    Term.Substitution.SubstVFresh

import-dirs:          /usr/lib/ghc-8.10.3/site-local/tamarin-prover-term-1.6.0
library-dirs:         /usr/lib/ghc-8.10.3/site-local/tamarin-prover-term-1.6.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.3/tamarin-prover-term-1.6.0

hs-libraries:         HStamarin-prover-term-1.6.0-HlGl4TzWZRaKQGUggghkNL
depends:
    HUnit-1.6.2.0-6Qz5k8URKehKv59h9ZmD3M
    attoparsec-0.13.2.4-3KIunrRLdh4G7KtfrdatRR base-4.14.1.0
    binary-0.8.8.0 bytestring-0.10.12.0 containers-0.6.2.1
    deepseq-1.4.4.0 dlist-1.0-CIVcjanACu2JJSNSgg81oy mtl-2.2.2
    process-1.6.9.0 safe-0.3.19-AfrHSVViU1189qUhjBUb5b
    tamarin-prover-utils-1.6.0-JAox8eye9deI15lnI0Sknn

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-term/html/tamarin-prover-term.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-term/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-tamarin-prover-term-1.6.0-53-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-tamarin-prover-term.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 tamarin-prover-term
version:              1.6.0
visibility:           public
id:                   tamarin-prover-term-1.6.0-6cQY72OelfTK6buorOWL16
key:                  tamarin-prover-term-1.6.0-6cQY72OelfTK6buorOWL16
license:              LicenseRef-GPL
copyright:
    Benedikt Schmidt, Simon Meier, Jannik Dreier, Ralf Sasse, ETH Zurich, 2010-2018

maintainer:
    Simon Meier <simon.meier@inf.ethz.ch>,
    Jannik Dreier <research@jannikdreier.net>,
    Ralf Sasse <ralf.sasse@gmail.com>

author:
    Benedikt Schmidt <benedikt.schmidt@inf.ethz.ch>,
    Simon Meier <simon.meier@inf.ethz.ch>,
    Jannik Dreier <research@jannikdreier.net>,
    Ralf Sasse <ralf.sasse@gmail.com>

homepage:             https://tamarin-prover.github.io/
synopsis:             Term manipulation library for the tamarin prover.
description:
    This is an internal library of the Tamarin prover for
    security protocol verification
    (<hackage.haskell.org/package/tamarin-prover>).

    This library provides term manipulation infrastructure
    (matching, unification, narrowing, finite variants) for
    the Tamarin prover. It uses maude
    (<http://maude.cs.uiuc.edu/>) as a backend for
    normalization, equational matching, and unification.

category:             Theorem Provers
abi:                  a7bec8f3a1825e6bfffb3d0082badc28
exposed:              True
exposed-modules:
    Term.Builtin.Convenience Term.Builtin.Rules Term.Builtin.Signature
    Term.LTerm Term.Maude.Parser Term.Maude.Process
    Term.Maude.Signature Term.Maude.Types Term.Narrowing.Variants
    Term.Narrowing.Variants.Check Term.Narrowing.Variants.Compute
    Term.Positions Term.Rewriting.Definitions Term.Rewriting.Norm
    Term.Substitution Term.Subsumption Term.SubtermRule
    Term.Unification Term.UnitTests Term.VTerm

hidden-modules:
    Term.Term Term.Term.Classes Term.Term.Raw Term.Term.FunctionSymbols
    Term.Narrowing.Narrow Term.Substitution.SubstVFree
    Term.Substitution.SubstVFresh

import-dirs:          /usr/lib/ghc-8.10.4/site-local/tamarin-prover-term-1.6.0
library-dirs:         /usr/lib/ghc-8.10.4/site-local/tamarin-prover-term-1.6.0
dynamic-library-dirs: /usr/lib
data-dir:
    /usr/share/x86_64-linux-ghc-8.10.4/tamarin-prover-term-1.6.0

hs-libraries:         HStamarin-prover-term-1.6.0-6cQY72OelfTK6buorOWL16
depends:
    HUnit-1.6.2.0-6Qz5k8URKehKv59h9ZmD3M
    attoparsec-0.13.2.5-HLmDNIwkLhHGlw3xuH7rpN base-4.14.1.0
    binary-0.8.8.0 bytestring-0.10.12.0 containers-0.6.2.1
    deepseq-1.4.4.0 dlist-1.0-IkgyT9tiSx2lrH2MHeV2o mtl-2.2.2
    process-1.6.9.0 safe-0.3.19-AfrHSVViU1189qUhjBUb5b
    tamarin-prover-utils-1.6.0-39efB2GD4QvG7On2pLcCoB

haddock-interfaces:
    /usr/share/doc/haskell-tamarin-prover-term/html/tamarin-prover-term.haddock

haddock-html:         /usr/share/doc/haskell-tamarin-prover-term/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
